@@ -15,8 +15,8 @@ class GenerateSlotDoctor:
         self._type = 'both'
         self._doctor_id = ''
         self._start_at = datetime.datetime.now()
-        self._end_at = ''
-        self._duration = 1
+        self._duration = 5
+        self._end_at = self._start_at + datetime.timedelta(minutes=int(self._duration))
         self._context = 'default'
         self._created_at = datetime.datetime.now()
         self._updated_at = datetime.datetime.now()
@@ -65,16 +65,16 @@ class GenerateSlotDoctor:
         list_slot_ids = []
         while (i <= self._count):
             slot_doctor = SlotsDoctors(doctor_id=self._doctor_id,
-                                type=self._type,
-                                start_at=self._start_at,
-                                duration=self._duration,
-                                end_at=self._end_at,
-                                context=self._context,
-                                created_at=self._created_at,
-                                updated_at=self._updated_at)
+                                       type=self._type,
+                                       start_at=self._start_at,
+                                       duration=self._duration,
+                                       end_at=self._end_at,
+                                       context=self._context,
+                                       created_at=self._created_at,
+                                       updated_at=self._updated_at)
             slot_doctor.save()
-            slot_id = model_to_dict(slot_doctor.get('id'))
-            list_slot_ids.append(slot_id)
+            print(slot_doctor.id)
+            list_slot_ids.append(slot_doctor.id)
             i = i + 1
             self._start_at = self._end_at
             self._end_at = self._start_at + datetime.timedelta(minutes=int(self._duration))
